RDFCalendar.FormatWriters

Package RDFCalendar :: Module FormatWriters |
[show private | hide private]
[frames | no frames]

## Module RDFCalendar.FormatWriters

    Format writer classes.

    Copyright (C) 2005, 2006 Paul Boddie <paul@boddie.org.uk>

    This program is free software; you can redistribute it and/or modify it under
    the terms of the GNU Lesser General Public License as published by the Free
    Software Foundation; either version 3 of the License, or (at your option) any
    later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
    FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
    details.

    You should have received a copy of the GNU Lesser General Public License along
    with this program.  If not, see <http://www.gnu.org/licenses/>.

Classes
`DOMWriter` | A DOM document writer.
`iCalendarWriter` | An iCalendar writer class.

Generated by Epydoc 2.1 on Tue Sep 18 23:33:17 2007 | http://epydoc.sf.net